Learn R Programming

ADPclust (version 0.6.5)

findFd: Find f(x) and delta(x) from a Data Set

Description

This function finds f(x) and delta(x) of each point x, where f(x) is the density estimation at each point, and delta(x) measures the distance between x to the closest point y such that f(y) > f(x). The output is used in 'findCluster()' and 'findClusterAuto()'.

Usage

findFd(dat, h = NULL, dmethod = "euclidean", htype = "AMISE", fdelta = "mnorm", verbose = FALSE)

Arguments

dat
a numeric matrix where rows are samples and columns are features.
h
nonnegative number or NULL (default). Bandwidth in density estimation. If NULL h is automatically selected.
dmethod
character string describing distance measures to use in dist(.. method = dmethod).
htype
integer vector. Number of clusters. Default = 5.
fdelta
character string that specifies the method to estimate densities at each data point. Default is "mnorm" stands for multivariate Gaussian density estimation. Other options include
verbose
if TRUE progress will be displayed.#'

Value

an R object with class "rd". If length(h) = 1 then "rd" is a list of the following items:
  • f: vector of f's
  • delta: vector of delta's
  • dat: the original data matrix
  • distm: distance matrix calculated from data (Euclidean distance))
  • dc: bandwith dc.
If h == NULL, then the function returns a list of length 15, where each item is a list corresponding to one h value.

Examples

Run this code
## data(clust3)
##findFd(clust3, h = 19, plot = TRUE)

Run the code above in your browser using DataLab