Learn R Programming

ADPclust (version 0.6.5)

plot.adpclust: Visualize the result of adpclust()

Description

Depends on the settings of adpclust, draw figures showing silhouette vs. number of clusters, f vs. delta with selected centroids, and original data (projected to the first two principal components if dim > 2) colored by cluster assignments.

Usage

"plot"(x, cols = "default", ...)

Arguments

x
an object of class "adpclust". Result of adpclust().
cols
vector of colors used to distinguish different clusters. Recycled if necessary.
...
Not used.

Examples

Run this code
## Load a data set with 3 clusters
data(clust3)
## Automatically select cluster centroids
ans <- adpclust(clust3, centroids = "auto")
plot(ans)

Run the code above in your browser using DataLab