Calculate the ROT bandwidth from either a data frame, or from p and n.
Usage
ROT(x, y = NULL)
Arguments
x
the number of variables (if y is missing), or a data frame or a matrix (if y is not missing).
y
the number of observations. If y is missing, x should be the data matrix.
Value
ROT bandwidth.
Details
IMPORTANT NOTE: The standard deviation of each variable is omitted in the formula here. For
computational consideration each dimension of the data is standardized before applying
the bandwidth. Two approaches are mathematically equivalent.