Depends on the settings of adpclust, draw figures showing silhouette vs. number of clusters, f vs. delta with selected centroids, and original data (projected to the first two principal components if dim > 2) colored by cluster assignments.
Usage
"plot"(x, cols = "default", ...)
Arguments
x
an object of class "adpclust". Result of adpclust().
cols
vector of colors used to distinguish different clusters. Recycled if necessary.